@@ -76,7 +76,7 @@ CreateTableOne2 <- function(data, strata, vars, factorVars, includeNA = F, test
   ptb1 <- print(res,
                showAllLevels = showAllLevels, printToggle = printToggle, quote = quote, smd = smd, varLabels = Labels, nonnormal = nonnormal, exact = exact,
                catDigits = catDigits, contDigits = contDigits, pDigits = pDigits)
-  rownames(ptb1) = gsub("(mean (sd))", "", rownames(ptb1), fixed=T)
+  rownames(ptb1) = gsub("(mean (SD))", "", rownames(ptb1), fixed=T)
   #cap.tb1 = paste("Table 1: Stratified by ", strata, sep="")
   
   if (Labels & !is.null(labeldata)){
@@ -168,7 +168,7 @@ CreateTableOneJS <- function(vars, strata = NULL, strata2 = NULL, data, factorVa
     ptb1 <- print(res,
                  showAllLevels = showAllLevels, printToggle = printToggle, quote = quote, smd = smd, varLabels = Labels, nonnormal = nonnormal,
                  catDigits = catDigits, contDigits = contDigits, pDigits = pDigits)
-    rownames(ptb1) <- gsub("(mean (sd))", "", rownames(ptb1), fixed=T)
+    rownames(ptb1) <- gsub("(mean (SD))", "", rownames(ptb1), fixed=T)
     cap.tb1 <- "Table 1: Total"
     if (Labels & !is.null(labeldata)){
       ptb1[,1] <- vals.tb1
@@ -233,7 +233,7 @@ CreateTableOneJS <- function(vars, strata = NULL, strata2 = NULL, data, factorVa
                 printToggle=F, quote=F, smd = smd, varLabels = T, exact = exact, nonnormal = nonnormal,
                 catDigits = catDigits, contDigits = contDigits, pDigits = pDigits)
     
-    rownames(ptb1) <- gsub("(mean (sd))", "", rownames(ptb1), fixed=T)
+    rownames(ptb1) <- gsub("(mean (SD))", "", rownames(ptb1), fixed=T)
     sig <- ifelse(ptb1[,"p"] == "<0.001", "0", ptb1[,"p"])
     sig <- as.numeric(as.vector(sig))
     sig <- ifelse(sig <= 0.05, "**", "")
